import 'package:flutter/material.dart';

class CurveContainer extends StatefulWidget {
  final Color? backgroundColor; // Screen background color
  final AppBar? appBar; // Navigation bar
  final double? appBarHeight; // Height of the sub header below the app bar
  final double? borderRadius; // Radius of the container
  final Widget? body; // Body of the containeer
  final Widget? subHeader; // widgets between app bar and container

  const CurveContainer(
      {Key? key,
      this.backgroundColor,
      this.appBar,
      this.appBarHeight,
      this.borderRadius,
      this.subHeader,
      this.body})
      : super(key: key);

  @override
  State<CurveContainer> createState() => _CurveContainerState();
}

class _CurveContainerState extends State<CurveContainer> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: widget.backgroundColor,
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          SizedBox(
            height: widget.appBarHeight,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                CustomAppBar(
                  backgroundColor: widget.backgroundColor,
                  title: widget.appBar!.title,
                  leading: widget.appBar!.title,
                  automaticallyImplyLeading:
                      widget.appBar!.automaticallyImplyLeading,
                  actions: widget.appBar!.actions,
                  flexibleSpace: widget.appBar!.flexibleSpace,
                  bottom: widget.appBar!.bottom,
                  elevation: widget.appBar!.elevation,
                  shadowColor: widget.appBar!.shadowColor,
                  shape: widget.appBar!.shape,
                  foregroundColor: widget.appBar!.foregroundColor,
                  iconTheme: widget.appBar!.iconTheme,
                  actionsIconTheme: widget.appBar!.actionsIconTheme,
                  primary: widget.appBar!.primary,
                  centerTitle: widget.appBar!.centerTitle,
                  excludeHeaderSemantics: widget.appBar!.excludeHeaderSemantics,
                  titleSpacing: widget.appBar!.titleSpacing,
                  toolbarOpacity: widget.appBar!.toolbarOpacity,
                  bottomOpacity: widget.appBar!.bottomOpacity,
                  toolbarHeight: widget.appBar!.toolbarHeight,
                  leadingWidth: widget.appBar!.leadingWidth,
                  toolbarTextStyle: widget.appBar!.toolbarTextStyle,
                  titleTextStyle: widget.appBar!.titleTextStyle,
                ),
                if (widget.subHeader != null) widget.subHeader!
              ],
            ),
          ),
          Expanded(
            child: Container(
              padding: EdgeInsets.only(
                  left: 0.0, right: 0.0, top: widget.borderRadius ?? 50.0),
              decoration: BoxDecoration(
                color: Colors.white,
                borderRadius: BorderRadius.only(
                  topLeft: Radius.circular(widget.borderRadius ?? 50.0),
                  topRight: Radius.circular(widget.borderRadius ?? 50.0),
                ),
              ),
              child: widget.body,
            ),
          ),
        ],
      ),
    );
  }
}

// ignore: must_be_immutable
class CustomAppBar extends StatefulWidget {
  Widget? leading;
  bool? automaticallyImplyLeading = false;
  Widget? title;
  List<Widget>? actions;
  Widget? flexibleSpace;
  PreferredSizeWidget? bottom;
  double? elevation;
  Color? shadowColor;
  ShapeBorder? shape;
  Color? backgroundColor;
  Color? foregroundColor;
  Brightness? brightness;
  IconThemeData? iconTheme;
  IconThemeData? actionsIconTheme;
  TextTheme? textTheme;
  bool? primary = true;
  bool? centerTitle;
  bool? excludeHeaderSemantics = false;
  double? titleSpacing;
  double? toolbarOpacity = 1.0;
  double? bottomOpacity = 1.0;
  double? toolbarHeight;
  double? leadingWidth;
  bool? backwardsCompatibility;
  TextStyle? toolbarTextStyle;
  TextStyle? titleTextStyle;

  CustomAppBar({
    Key? key,
    this.leading,
    this.automaticallyImplyLeading,
    this.title,
    this.actions,
    this.flexibleSpace,
    this.bottom,
    this.elevation,
    this.shadowColor,
    this.shape,
    this.backgroundColor,
    this.foregroundColor,
    this.brightness,
    this.iconTheme,
    this.actionsIconTheme,
    this.textTheme,
    this.primary,
    this.centerTitle,
    this.excludeHeaderSemantics,
    this.titleSpacing,
    this.toolbarOpacity,
    this.bottomOpacity,
    this.toolbarHeight,
    this.leadingWidth,
    this.backwardsCompatibility,
    this.toolbarTextStyle,
    this.titleTextStyle,
  }) : super(key: key);

  @override
  State<CustomAppBar> createState() => _CustomAppBarState();
}

class _CustomAppBarState extends State<CustomAppBar> {
  @override
  Widget build(BuildContext context) {
    return AppBar(
      elevation: 0,
      backgroundColor: widget.backgroundColor,
      title: widget.title,
    );
  }
}
